aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-dvbci.c
diff options
context:
space:
mode:
authorEvan Huus <eapache@gmail.com>2013-12-19 16:28:39 +0000
committerEvan Huus <eapache@gmail.com>2013-12-19 16:28:39 +0000
commit2ae8edccea07234fa916d0fb7193f28fb0783ab4 (patch)
tree8b76205aaa5bf9eddde8f313ef90e4c4212a4002 /epan/dissectors/packet-dvbci.c
parenta6415ece0ad102d30ac5dce59b127bcf1bd6d3f1 (diff)
Rename more to_str functions to have ep_ in the name if they return ephemeral
buffers. Remove two unused functions. svn path=/trunk/; revision=54250
Diffstat (limited to 'epan/dissectors/packet-dvbci.c')
-rw-r--r--epan/dissectors/packet-dvbci.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/epan/dissectors/packet-dvbci.c b/epan/dissectors/packet-dvbci.c
index cad347c2ed..46881ce60b 100644
--- a/epan/dissectors/packet-dvbci.c
+++ b/epan/dissectors/packet-dvbci.c
@@ -2777,7 +2777,7 @@ dissect_dvbci_payload_dt(guint32 tag, gint len_field,
}
else {
col_append_sep_fstr(pinfo->cinfo, COL_INFO, NULL,
- "update every %s", rel_time_to_str(&resp_intv));
+ "update every %s", rel_time_to_ep_str(&resp_intv));
}
}
else if (tag==T_DATE_TIME) {
@@ -2797,7 +2797,7 @@ dissect_dvbci_payload_dt(guint32 tag, gint len_field,
proto_tree_add_time(tree, hf_dvbci_utc_time,
tvb, offset, time_field_len, &utc_time);
col_append_sep_fstr(pinfo->cinfo, COL_INFO, ": ", "%s UTC",
- abs_time_to_str(&utc_time, ABSOLUTE_TIME_UTC, FALSE));
+ abs_time_to_ep_str(&utc_time, ABSOLUTE_TIME_UTC, FALSE));
offset += time_field_len;
if (len_field==7) {
@@ -3263,7 +3263,7 @@ dissect_dvbci_payload_cc(guint32 tag, gint len_field _U_,
break;
}
else {
/* abs_time_to_str() never returns NULL */
proto_tree_add_time(tree, hf_dvbci_pin_chg_time,
tvb, offset, UTC_TIME_LEN, &utc_time);
}
@@ -3263,7 +3263,7 @@ dissect_dvbci_payload_cc(guint32 tag, gint len_field _U_,
}
else {
- /* abs_time_to_str() never returns NULL */
+ /* abs_time_to_ep_str() never returns NULL */
proto_tree_add_time(tree, hf_dvbci_pin_chg_time,
tvb, offset, UTC_TIME_LEN, &utc_time);